
/**
 *  Copyright (c) 2015, Facebook, Inc.
 *  All rights reserved.
 *
 *  This source code is licensed under the BSD-style license found in the
 *  LICENSE file in the root directory of this source tree. An additional grant
 *  of patent rights can be found in the PATENTS file in the same directory.
 */

'use strict';

var _Object$keys = require('babel-runtime/core-js/object/keys')['default'];

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports['default'] = InterfacePossibleTypesMustImplementTheInterface;

var _error = require('../../error');

var _definition = require('../definition');

function InterfacePossibleTypesMustImplementTheInterface(context) {
  var schema = context.getSchema();
  var typeMap = schema.getTypeMap();
  var errors = [];

  _Object$keys(typeMap).forEach(function (typeName) {
    var type = typeMap[typeName];
    if (!(type instanceof _definition.GraphQLInterfaceType)) {
      return;
    }
    var possibleTypes = type.getPossibleTypes();
    possibleTypes.forEach(function (possibleType) {
      if (possibleType.getInterfaces().indexOf(type) === -1) {
        errors.push(new _error.GraphQLError(possibleType + ' is a possible type of interface ' + type + ' but does ' + 'not implement it!'));
      }
    });
  });

  return errors.length > 0 ? errors : null;
}

module.exports = exports['default'];